@@ -1,9 +1,9 @@
 use strict;
 package Inline::Foo;
-$Inline::Foo::VERSION = '0.01';
 
 require Inline;
-@Inline::Foo::ISA = qw(Inline);
+our @ISA = qw(Inline);
+our $VERSION = '0.58';
 
 use Carp;
 use File::Spec;
@@ -54,6 +54,7 @@ sub build {
     $code =~ s/bar-//g if $o->{ILSM}{BAR};
     {
         package Foo::Tester;
+        our $VERSION = '0.02';
         eval $code;
     }
     croak "Foo build failed:\n$@" if $@;
